@@ -1,7 +1,12 @@
 print.outlierTest <- function(x, ...) {
   if (!inherits(x, "outlierTest"))
     stop("Use only with 'outlierTest' objects.\n")
-  test <- (x$pos+1)/(x$R+1)
+  thestat <- x$t0[1]
+  thestat <- ifelse(thestat<0.0,0.0,thestat)
+  nullstat <- x$t[,1]
+  nullstat <- ifelse(nullstat<0.0,0.0,nullstat)
+  pos <- sum(nullstat>thestat)
+  test <- (pos+1)/(length(x$t[,1])+1)
   out <- sprintf("p value %1.4f", test)
   cat(out)
   invisible(out)
@@ -17,7 +22,12 @@ summary.outlierTest <- function(object,...) {
 print.summary.outlierTest <- function(x,...) {
   if (!inherits(x, "summary.outlierTest"))
     stop("Use only with 'summary.outlierTest' objects.\n")
-  test <- (x$pos+1)/(x$R+1)
+  thestat <- x$t0[1]
+  thestat <- ifelse(thestat<0.0,0.0,thestat)
+  nullstat <- x$t[,1]
+  nullstat <- ifelse(nullstat<0.0,0.0,nullstat)
+  pos <- sum(nullstat>thestat)
+  test <- (pos+1)/(length(x$t[,1])+1)
   out <- sprintf("p value %1.4f", test)
   cat(out)
   invisible(out)
